.. _dev-contributing:

####################
 General guidelines
####################

Thank you for your interest in Anemoi Inference! Please follow the
:ref:`general Anemoi contributing guidelines
<anemoi-docs:contributing>`.

These include general guidelines for contributions to Anemoi,
instructions on setting up a development environment, and guidelines on
collaboration on GitHub, writing documentation, testing, and code style.

************
 Unit tests
************

Anemoi-inference includes unit tests that can be executed locally using
pytest. For more information on testing, please refer to the
:ref:`general Anemoi testing guidelines
<anemoi-docs:testing-guidelines>`.
